#!/usr/bin/env python3

from opencore.build import OpenCoreBuild


if __name__ == '__main__':
    build = OpenCoreBuild('Volumes/EFI')
    build.kexts = [
       {
            'project': 'ASPP-Override',
            'properties': {
                'ExecutablePath': '',
                'MinKernel': '21.4.0'
            },
            'repo': 'dortania',
            'version': '1.0.1'
        },
        {
            'project': 'Lilu',
            'repo': 'acidanthera',
            'version': '1.6.4'
        },
 #       {
 #           'project': 'FeatureUnlock',
 #           'repo': 'acidanthera',
 #           'version': '1.1.3'
 #       },
        {
            'project': 'WhateverGreen',
            'repo': 'acidanthera',
            'version': '1.6.4'
        }
    ]
    build.write_tree()

    settings = {
		'Booter': {
			'Quirks': {
			'ForceBooterSignature': True
			}
		},
		'DeviceProperties': {
			'Add': {
				'PciRoot(0x0)/Pci(0x3,0x0)/Pci(0x0,0x0)': {
					'rebuild-device-tree': 0,
					'unfairgva': 1
				},
				'PciRoot(0x0)/Pci(0x1,0x0)/Pci(0x0,0x0)/Pci(0x4,0x0)/Pci(0x0,0x0)': {
					'built-in': build.unhexlify('00')
				}
			}
		},
		'Kernel': {
			'Quirks': {
				'DisableLinkeditJettison': True,
				'SetApfsTrimTimeout': 0,
				'ThirdPartyDrives': True
			}
		},
		'Misc': {
			'Boot': {
				'HideAuxiliary': False,
				'LauncherOption': 'Full',
				'PollAppleHotKeys': True,
				'PickerMode': 'External',
				'PickerAttributes': 80,
				'PickerVariant': 'Default',
				'ShowPicker': True,
                'Timeout': 15,
                'HibernateSkipsPicker': True
			},
			'Security': {
				'AllowSetDefault': True,
				'BlacklistAppleUpdate': True,
				'ExposeSensitiveData': 0,
				'ScanPolicy': 0,
				'SecureBootModel': 'Default',
				'Vault': 'Optional'
			}
		},
		'NVRAM': {
			'Add': {
				'7C436110-AB2A-4BBB-A880-FE41995C9F82': {
					'boot-args': 'keepsyms=1'
				}
			},
			'WriteFlash': True
		},
		'PlatformInfo': {
			'DataHub': {
				'BoardProduct': 'Mac-27AD2F918AE68F61'
			},
			'PlatformNVRAM': {
				'FirmwareFeatures': build.unhexlify('03 54 0C C0 08 00 00 00'),
				'FirmwareFeaturesMask': build.unhexlify('3F FF 1F FF 08 00 00 00')
			},
			'SMBIOS': {
				'BoardProduct': 'Mac-27AD2F918AE68F61'
			},
			'UpdateDataHub': True,
			'UpdateNVRAM': True,
			'UpdateSMBIOS': True
		},
		'UEFI': {
			'AppleInput': {
				'AppleEvent': 'Builtin'
			},
			'ConnectDrivers': True,
			'Drivers': [
				{
					'Arguments': '',
					'Comment': '',
					'Enabled': True,
					'LoadEarly': False,
					'Path': 'OpenCanopy.efi'
				},
				{
					'Arguments': '',
					'Comment': '',
					'Enabled': True,
					'LoadEarly': False,
					'Path': 'OpenRuntime.efi'
				}
			],
			'Input': {
				'TimerResolution': 100000
			},
			'Output': {
				'DirectGopRendering': False, 
				'ProvideConsoleGop': True,
				#'GopBurstMode': False,  # for OC091 may experiment with true to see if it boots
				'Resolution': 'Max',
				'UIScale': 0
			},
			'ProtocolOverrides': {
				'AppleBootPolicy': False,
				'AppleUserInterfaceTheme': True
			},
			'Quirks': {
				'RequestBootVarRouting': True
			}
		}
	}
    build.write_plist(settings)
    build.run_misc_tasks()
